@@ -2,9 +2,9 @@
 
 Result hashmap_erase(register HashMap *map, char const *name, SymbolType type)
 {
-    register unsigned idx = hm_find_idx(map, name, type);
+    register size_t idx = hm_find_idx(map, name, type);
 
-    if (idx == FAILED)
+    if (idx == UFAILED)
         return idx;
 
     hashitem_erase(map->d_map[idx]);
